5. smallanglescattering (sas) — Jscatter 1.3.0.7 documentation

# 5. smallanglescattering (sas)

## 5.1. SAS smear/desmear 1D

The preferred method for convolution with instrument resolution is smear. smear modifies model functions to automatically extend the q range beyond edges for proper smearing as needed to fit smeared SANS/SAXS data. Smearing explicit data by smear or resFunct needs additional information how to extrapolate data at the detector edges. See smear for detailed explanation. Needed beamProfiles are prepared by prepareBeamProfile.

## 5.2. SAS convenience

## 5.3. 2D sasImage

### 5.3.1. sasImage methods

Proccessing/Calibration

Masking

Attributes

## 5.4. 2D sasImage convenience

## 5.5. Housekeeping